
/* Chrysalide - Outil d'analyse de fichiers binaires
 * constants.c - équivalent Python partiel du fichier "plugins/dex/dex_def.h"
 *
 * Copyright (C) 2018 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "constants.h"


#include <format/symbol.h>


#include "../helpers.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : type = type dont le dictionnaire est à compléter.            *
*                                                                             *
*  Description : Définit les constantes pour le format Dex.                   *
*                                                                             *
*  Retour      : true en cas de succès de l'opération, false sinon.           *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool define_binary_symbol_constants(PyTypeObject *type)
{
    bool result;                            /* Bilan à retourner           */
    PyObject *values;                       /* Groupe de valeurs à établir */

    values = PyDict_New();

    result = add_const_to_group(values, "DATA", STP_DATA);
    if (result) result = add_const_to_group(values, "ROUTINE", STP_ROUTINE);
    if (result) result = add_const_to_group(values, "CODE_LABEL", STP_CODE_LABEL);
    if (result) result = add_const_to_group(values, "OBJECT", STP_OBJECT);
    if (result) result = add_const_to_group(values, "ENTRY_POINT", STP_ENTRY_POINT);
    if (result) result = add_const_to_group(values, "RO_STRING", STP_RO_STRING);
    if (result) result = add_const_to_group(values, "DYN_STRING", STP_DYN_STRING);
    if (result) result = add_const_to_group(values, "COUNT", STP_COUNT);

    if (!result)
    {
        Py_DECREF(values);
        goto exit;
    }

    result = attach_constants_group_to_type(type, false, "SymbolType", values,
                                            "Available values for symbol types.");

    values = PyDict_New();

    result = add_const_to_group(values, "INTERNAL", SSS_INTERNAL);
    if (result) result = add_const_to_group(values, "EXPORTED", SSS_EXPORTED);
    if (result) result = add_const_to_group(values, "IMPORTED", SSS_IMPORTED);
    if (result) result = add_const_to_group(values, "DYNAMIC", SSS_DYNAMIC);

    if (!result)
    {
        Py_DECREF(values);
        goto exit;
    }

    result = attach_constants_group_to_type(type, false, "SymbolStatus", values,
                                            "Status of a symbol visibility.");

 exit:

    return result;

}
